



csvclean --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvcut --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvformat --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvgrep --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvjoin --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvjson --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvlook --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvpy --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvsort --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvsql --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvstack --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
csvstat --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
in2csv --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
sql2csv --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
